==> voxstorm-0.1.4.tar.bz2: voxstorm-0.1.4/src/wmixdowndialog.h <==
/***************************************************************************/
/*! \file   wmixdowndialog.h
    \brief  饹WMixdownDialogΥإåե롣
    \author Tomoaki Murakami
    \date   2004ǯ  5 18  23:59:12 JST
*/
/***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _WMIXDOWNDIALOG_H_
#define _WMIXDOWNDIALOG_H_

#include <qstring.h>
#include <qcheckbox.h>
#include <kdialogbase.h>
#include "wfilechooser.h"
#include "cecaiamanager.h"

/*-------------------------------------------------------------------------*/
/*! \class  WMixdownDialog
    \brief  ߥå
*/
/*-------------------------------------------------------------------------*/
class WMixdownDialog : public KDialogBase
{
  Q_OBJECT

public:
  //! \brief 󥹥ȥ饯
  //! \param WidgetParent ƥåȤؤΥݥ󥿡
  //! \param cName å̾Ρ
  WMixdownDialog(QWidget* WidgetParent=0, const char* cName=0);
  //! \breif ǥȥ饯
  ~WMixdownDialog();

  //! \brief ʤߥå򤹤뤫ɤ֤
  bool mixesWithPlaying() const;
  //! \brief ߥåե̾Τ֤
  QString fileName() const;

private:
  //! ʤߥå󤹤뤫ɤꤹ뤿Υåȡ
  QCheckBox    *CheckBoxWithPlaying;
  //! ߥåեΤΥåȡ
  WFileChooser *FileChooserMixdown;

protected slots:
  //! \brief OKå줿Υåȡ
  void slotOk();

private slots:
  //! \breif FileChooserMixdownΥե̾Τѹ줿Υåȡ
  //! \param strFileName ե̾Ρ
  void slotChangedFileName(const QString& strFileName);
};

#endif

==> voxstorm-0.2.0.tar.bz2: voxstorm-0.2.0/src/wmixdowndialog.h <==
/***************************************************************************/
/*! \file   wmixdowndialog.h
    \brief  饹WMixdownDialogΥإåե롣
    \author Tomoaki Murakami
    \date   2004ǯ  5 18  23:59:12 JST
*/
/***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef WMIXDOWNDIALOG_H
#define WMIXDOWNDIALOG_H

#include <qstring.h>
#include <qcheckbox.h>
#include <kdialogbase.h>
#include "wfilechooser.h"
#include "cecaiamanager.h"

/*-------------------------------------------------------------------------*/
/*! \class  WMixdownDialog
    \brief  ߥå
*/
/*-------------------------------------------------------------------------*/
class WMixdownDialog : public KDialogBase
{
  Q_OBJECT

public:
  //! \brief 󥹥ȥ饯
  //! \param WidgetParent ƥåȤؤΥݥ󥿡
  //! \param cName å̾Ρ
  WMixdownDialog(QWidget* WidgetParent=0, const char* cName=0);
  //! \breif ǥȥ饯
  ~WMixdownDialog();

  //! \brief ʤߥå򤹤뤫ɤ֤
  bool mixesWithPlaying() const;
  //! \brief ߥåե̾Τ֤
  QString fileName() const;

private:
  //! ʤߥå󤹤뤫ɤꤹ뤿Υåȡ
  QCheckBox    *CheckBoxWithPlaying;
  //! ߥåեΤΥåȡ
  WFileChooser *FileChooserMixdown;

protected slots:
  //! \brief OKå줿Υåȡ
  void slotOk();

private slots:
  //! \breif FileChooserMixdownΥե̾Τѹ줿Υåȡ
  //! \param strFileName ե̾Ρ
  void slotChangedFileName(const QString& strFileName);
};

#endif
